@@ -14,4 +14,10 @@ describe 'scope' do
     @klass.scope :foo, ->(v) { { conditions: v } }
     assert_deprecated { @klass.foo(:bar) }.where_values.must_equal [:bar]
   end
+
+  it 'supports chaining' do
+    @klass.scope :foo, -> { @klass.where(:foo) }
+    assert_deprecated { @klass.scope :bar, conditions: :bar }
+    @klass.foo.bar.where_values.must_equal [:foo, :bar]
+  end
 end
